# -*- coding: utf-8 -*-
""" API to CRUD configuration settings for personalization

.. moduleauthor:: Rohan Monga <rohan@whisper.sh>

"""
import logging

import kazoo
from kazoo.client import KazooClient
from .Deployment import get_deployment_mode, get_zookeeper_host

ZOOKEEPER_HOSTS = get_zookeeper_host()
DEPLOYMENT_MODE = get_deployment_mode()

# TODO: i dont know how to fix this :(
ZOOKEEPER_ROOT = "/datascience/personalization"

zk = None


def connect():
    global zk
    zk = KazooClient(ZOOKEEPER_HOSTS, timeout=1)
    zk.start()


def disconnect():
    global zk
    zk.stop()


def is_connected():
    global zk
    return zk.connected


# TODO: cache this ?
def get_config(key, default=None, deployment_mode=DEPLOYMENT_MODE):
    global zk
    if not zk.connected:
        zk.restart()
    try:
        value = zk.get(_get_path(deployment_mode, key))[0]
        logging.getLogger(__name__).info("{0:s}={1:s}".format(key, value))
        return value
    except kazoo.exceptions.NoNodeError:
        logging.getLogger(__name__).warn(
            "{0:s} config not found in zookeeper returning default={1:s}".format(key, default))
        return default


def set_config(key, value, deployment_mode=DEPLOYMENT_MODE):
    global zk
    full_path = _get_path(deployment_mode, key)
    logging.getLogger(__name__).info("Setting {0:s} to {1:s}".format(full_path, value))
    if zk.exists(full_path):
        return zk.set(full_path, str(value))
    else:
        return zk.create(full_path, str(value))


def delete_config(key, deployment_mode=DEPLOYMENT_MODE):
    global zk
    full_path = _get_path(deployment_mode, key)
    logging.getLogger(__name__).info("Deleting {0:s}".format(full_path))
    return zk.delete(full_path)


def _get_path(mode, path):
    return "/".join((ZOOKEEPER_ROOT, mode.name, path))


def create_if_not_exist(deployment_modes, path, value):
    global zk
    for mode in deployment_modes:
        full_path = _get_path(mode, path)
        if not zk.exists(full_path):
            logging.getLogger(__name__).info("Creating {0:s} = {1:s}".format(full_path, value))
            zk.create(_get_path(mode, path), value)
        else:
            logging.getLogger(__name__).info("Already exists {0:s}".format(full_path))
