# -*- coding: utf-8 -*-
"""Logging

.. moduleauthor:: Rohan Monga <rohan@whisper.sh>

"""
import json
import logging
import types
import sys

python_version = sys.version_info.major


def get_class_name(o):
    """return the fully qualified class name including the module name

    :param o:
    :return:
    """
    if o is None:
        return None
    elif isinstance(o, types.ModuleType):
        return o.__name__
    elif type(o) is type:
        name = o.__name__
    elif isinstance(o, types.FunctionType):
        name = o.__name__
    else:
        name = o.__class__.__name__

    return "{0:s}.{1:s}".format(o.__module__, name)


def get_logger(o):
    """Get logger object with the name properly setup

    :param o:
    :return:
    """
    if isinstance(o, str):
        return logging.getLogger(o)
    return logging.getLogger(get_class_name(o))


class DSFormatter(logging.Formatter):
    skip_list = ('args', 'asctime', 'created', 'exc_info', 'exc_text', 'filename',
                 'funcName', 'id', 'levelname', 'levelno', 'lineno', 'module',
                 'msecs', 'msecs', 'message', 'msg', 'name', 'pathname', 'process',
                 'processName', 'relativeCreated', 'thread', 'threadName', 'extra')

    def format(self, record):
        _msg = super(DSFormatter, self).format(record)
        _extra = {}
        for key in record.__dict__:
            if key not in self.skip_list:
                _extra[key] = getattr(record, key)
        if _extra:
            return _msg + " " + json.dumps(_extra)
        else:
            return _msg
