# -*- coding: utf-8 -*-
"""

.. moduleauthor:: Rohan Monga <rohan@whisper.sh>

"""
import time

from decorator import decorator
from line_profiler import LineProfiler
from statsd.defaults.env import statsd

from .Logging import get_logger, get_class_name


@decorator
def profile_each_line(func, *args, **kwargs):
    profiler = LineProfiler()
    profiled_func = profiler(func)
    try:
        results = profiled_func(*args, **kwargs)
    finally:
        print("-" * 80)
        print(func.__name__)
        profiler.print_stats()
        print("-" * 80)
        print()
    return results


@decorator
def log_time(func, *args, **kwargs):
    start = time.time()
    try:
        result = func(*args, **kwargs)
    finally:
        took = 1000 * (time.time() - start)
        func_name = get_class_name(func)
        get_logger(func).info("took {1} ms".format(func_name, took), extra={'took': took})
        statsd.timing(func_name + ".took", took)

    return result
