# -*- coding: utf-8 -*-
"""Timestamp manipulation

.. moduleauthor:: Rohan Monga <rohan@whisper.sh>

"""
import calendar
from datetime import datetime
from datetime import timedelta


def start_day_from_ts(ts):
    day_from_ts = datetime.fromtimestamp(ts)
    return calendar.timegm(datetime(day_from_ts.year, day_from_ts.month, day_from_ts.day).timetuple())


def ts_ago(days=0, seconds=0, minutes=0, hours=0, weeks=0):
    return calendar.timegm((datetime.utcnow() - timedelta(days=days,
                                                          seconds=seconds,
                                                          minutes=minutes,
                                                          hours=hours,
                                                          weeks=weeks)
                            ).timetuple())


def milli_ts(ts):
    return ts * 1000


def mega_ts(ts):
    return ts * 1000000


def generate_index_names(days_ago, prefix="whisper", delimiter="-"):
    """Generate list of indices to query. They are usually formatted as {prefix}-{year}-{month}-{day}

    :param days_ago: number of index names to generate
    :type days_ago: int
    :param prefix: index name prefix. e.g. nearby / whisper
    :type prefix: basestring
    :return:
    :rtype: list
    """
    index_names = []
    for d in range(days_ago+1):
        day = datetime.utcnow() - timedelta(d)
        index_names.append('{1:s}{0:s}day{0:s}{2:d}{0:s}{3:d}{0:s}{4:d}'.format(delimiter,
                                                                                prefix,
                                                                                day.year,
                                                                                day.month,
                                                                                day.day))
    return index_names
