# -*- coding: utf-8 -*-
"""
    wdslib.pytools
    ~~~~~~~~~~~~~~

    helpers that make python related tasks easier

"""
import logging
import collections
import itertools

import erlang


def lazyprop(fn):
    __doc__ = fn.__doc__
    attr_name = '_lazy_' + fn.__name__

    @property
    def _lazyprop(self):
        if not hasattr(self, attr_name):
            setattr(self, attr_name, fn(self))
        return getattr(self, attr_name)

    return _lazyprop


def recursively_default_dict():
    return collections.defaultdict(recursively_default_dict)


def to_int(char, default_value=None):
    if char is None:
        return default_value
    try:
        return int(char)
    except ValueError:
        logging.getLogger(__name__).warn("Cannot cast {0:s} to int, return {1:s}".format(char, default_value))
        return default_value


def to_float(char, default_value=None):
    if char is None:
        return default_value
    try:
        return float(char)
    except ValueError:
        logging.getLogger(__name__).warn("Cannot cast {0:s} to float, return {1:s}".format(char, default_value))
        return default_value


def erlang_to_python(item):
    item_type = type(item)
    if item_type in {erlang.OtpErlangAtom, erlang.OtpErlangBinary}:
        return item.value
    elif item_type is tuple:
        converted_list = [erlang_to_python(element) for element in item]
        converted_list_no_struct = [element for element in converted_list if not element == 'struct']
        if len(converted_list_no_struct) == 1:
            return converted_list_no_struct[0]
        else:
            return tuple(converted_list_no_struct)
    elif item_type is list:
        converted_list = [erlang_to_python(element) for element in item]
        if len([i for i in converted_list if type(i) is tuple and len(i) == 2]) == len(converted_list):
            return dict(converted_list)
        else:
            return converted_list
    elif item_type is dict:
        return {erlang_to_python(k): erlang_to_python(v) for (k, v) in item.iteritems()}
    else:
        return item


def chunks(l, n):
    """ Yield successive n-sized chunks from l.
    :param l: list to be broken up in to chunks
    :type l: list
    :param n: chunk size
    :type n: int
    :rtype : list
    """
    for i in range(0, len(l), n):
        yield [item for item in itertools.islice(l, i, i + n)]


from .StopWords import ENGLISH_STOP_WORDS
