# -*- coding: utf-8 -*-
"""

.. moduleauthor:: Rohan Monga <rohan@whisper.sh>

"""
import json

import elasticsearch
import requests
from ..pytools.Time import ts_ago, mega_ts


def _make_user_query(q):
    r = requests.get(q)
    return r.json()['response']['docs']


def _make_whisper_query(q):
    r = requests.get(q)
    return r.json()['response']['docs']


def get_uid_recently_active(limit=5):
    ts = mega_ts(ts_ago(days=1))
    query = "http://cassandra-user-solr-01.w:8983/solr/users.users_v2/select?q=*:*&fq=last_login:[{ts} TO *]&sort=me2_count+desc&rows={limit}&wt=json"
    query = query.format(ts=ts, limit=limit)
    retval = []
    for r in _make_user_query(query):
        retval.append(r['uid'])
    return retval


def get_uid_inside_walled_garden():
    query = "http://cassandra-user-solr-01.w:8983/solr/users.users_v2/select?q=*:*&fq=is_inside_walled_garden:true&sort=last_login+desc&rows=1&wt=json"
    return _make_user_query(query)[0]['uid']


def get_uid_outside_walled_garden():
    query = "http://cassandra-user-solr-01.w:8983/solr/users.users_v2/select?q=*:*&fq=is_inside_walled_garden:false&sort=last_login+desc&rows=1&wt=json"
    return _make_user_query(query)[0]['uid']


def get_uid_with_location():
    query = "http://cassandra-user-solr-01.w:8983/solr/users.users_v2/select?q=*:*&fq=location_permission_level:background&sort=last_login+desc&rows=1&wt=json&fl=uid"
    return _make_user_query(query)[0]['uid']


def get_uid_with_tribes():
    query = "http://haproxy.whisper.sh:8901/solr/users.users_v2/select?q=*:*&fq=feeds:/.*tribe.*/&sort=me2_count+desc&wt=json&rows=1"
    return _make_user_query(query)[0]['uid']


def get_tribe_with_whispers(limit=1):
    query = "http://solr-whisper-01.w:8983/solr/whispers.whispers/select?q=feeds:/.*tribe.*/&wt=json&rows={0}".format(
        limit * 5)

    retval = set()
    for w in _make_whisper_query(query):
        for f in json.loads(w['feeds']):
            if f['feed_type'] == 'tribe':
                retval.add(f['id'])
    return list(retval)[:limit]


def get_whisper_nsfw():
    query = "http://solr-whisper-01.w:8983/solr/whispers.whispers/select?q=*:*&fq=deleted:false%20AND%20carlin:%5B0.8%20TO%20*%5D&wt=json&rows=1"

    for w in _make_whisper_query(query):
        return w['wid']


def get_whisper_inside_walled_garden():
    query = "http://solr-whisper-01.w:8983/solr/whispers.whispers/select?q=*:*&fq=deleted:false%20AND%20inside_walled_garden:true&wt=json&rows=1"
    for w in _make_whisper_query(query):
        return w['wid']


def get_whisper_outside_walled_garden():
    query = "http://solr-whisper-01.w:8983/solr/whispers.whispers/select?q=*:*&fq=deleted:false%20AND%20inside_walled_garden:false&wt=json&rows=1"
    for w in _make_whisper_query(query):
        return w['wid']


def get_whisper_meetup():
    query = "http://haproxy.whisper.sh:8900/solr/whispers.whispers/select?q=feed_ids:%22d9caadec-b93b-11e3-b96a-2a2b5736098b%22&wt=json&rows=10"
    for w in _make_whisper_query(query):
        return w['wid']
