import cPickle

from . import Vectorizer
from ..utils import pad_sequences

class OrdSequencer(Vectorizer):
    def __init__(self, original_sequence_length, reply_sequence_length=None):
        super(OrdSequencer, self).__init__()
        self.original_sequence_length = original_sequence_length
        self.reply_sequence_length = reply_sequence_length

    def get_pad_value(self):
        return 0.

    def vectorize(self, text, maxlen=None, pad=True, padding='pre'):
        if maxlen is None:
            maxlen = self.original_sequence_length
        if isinstance(text, basestring):  # if it's one document
            seq = map(ord, text)
            if pad:
                seq = pad_sequences([seq], maxlen=maxlen, value=self.get_pad_value(), padding=padding)
            return seq
        elif isinstance(text, (list, tuple)):  # if it's a bunch of documents
            seqs = [map(ord, t) for t in text]
            if pad:
                seqs = pad_sequences(seqs, maxlen=maxlen, value=self.get_pad_value(), padding=padding)
            return seqs
