import cPickle

from . import Vectorizer
from ..utils import pad_sequences

class Sequencer(Vectorizer):
    def __init__(self, original_sequence_length, reply_sequence_length=None, vocab=None):
        super(Sequencer, self).__init__()
        self.original_sequence_length = original_sequence_length
        self.reply_sequence_length = reply_sequence_length
        if vocab is None:
            self.vocab = {}
        else:
            self.vocab = vocab

    def get_unkidx(self):
        return len(self.vocab)

    def get_pad_value(self):
        return 0.

    def load(self, filename):
        with open(filename, "rb") as f:
            self.vocab = cPickle.load(f)
        return self

    def vectorize(self, text, maxlen=None):
        if maxlen is None:
            maxlen = self.original_sequence_length
        if isinstance(text, basestring):  # if it's one document
            seq = [self.vocab.get(word, self.get_unkidx()) for word in text.split()]
            seq = pad_sequences([seq], maxlen=maxlen, value=self.get_pad_value())
            return seq
        elif isinstance(text, (list, tuple)):  # if it's a bunch of documents
            seqs = [[self.vocab.get(word, self.get_unkidx()) for word in t.split()] for t in text]
            return pad_sequences(seqs, maxlen=maxlen, value=self.get_pad_value())
