import multiprocessing
import cPickle

import gensim

from . import Vectorizer
from ..utils import pad_sequences

class Word2VecEmbedder(Vectorizer):
    def __init__(self, embedding_dim = 256, sequence_length = 100, sentences = None, min_count = 5, max_vocab_size = None, sg = 1, window = 5, workers = multiprocessing.cpu_count() - 1, iter = 5):
        self.w2v = gensim.models.word2vec.Word2Vec(
            sentences = sentences,
            size = embedding_dim,
            sg = sg,
            window = window, 
            workers = workers, 
            iter = iter, 
            min_count = min_count,
            max_vocab_size = max_vocab_size
        )
        self.embedding_dim = embedding_dim
        self.seqlen = sequence_length

    def get_unkidx(self):
        return len(self.w2v.vocab)

    def get_pad_value(self):
        try:
            return self.w2v.null_word
        except:
            return 0.

    def train(self, texts):
        if not isinstance(texts, list):
            raise Exception("input must be list of texts")
        sentences = map(lambda s: s.split(), texts)
        self.w2v.build_vocab(sentences=sentences)
        self.w2v.train(sentences=sentences)
        self.w2v.init_sims(replace=True)
        return self

    def save(self, filename):
        self.w2v.save(filename)

    def save_vocab(self, filename):
        with open(filename, "wb") as f:
            cPickle.dump(self.w2v.vocab, f, protocol=cPickle.HIGHEST_PROTOCOL)

    def load(self, filename):
        self.w2v = gensim.models.word2vec.Word2Vec.load(filename)
        # depends on gensim versions
        try: 
            self.embedding_dim = self.w2v.vector_size
        except: 
            self.embedding_dim = self.w2v.size 
        return self

    def vectorize(self, text, maxlen=None):
        if maxlen is None:
            maxlen = self.seqlen
        if isinstance(text, basestring):  # if it's one document
            seq = [self.w2v.vocab[word].index if word in self.w2v.vocab else self.get_unkidx() for word in text.split()]
            return pad_sequences([seq], maxlen=maxlen, value=self.get_pad_value())
        elif isinstance(text, (list, tuple)):  # if it's a bunch of documents
            seqs = [[self.w2v.vocab[word].index if word in self.w2v.vocab else self.get_unkidx() for word in t.split()] for t in text]
            return pad_sequences(seqs, maxlen=maxlen, value=self.get_pad_value())
