import sys
from sklearn.feature_extraction.text import CountVectorizer

from . import BOWVectorizer,Sequencer, Word2VecEmbedder

texts = ["i love my mommy", "i love my dad", "i love my dog", "data science is cool"]

def test_bow_vectorizer():
    vect = BOWVectorizer(model=CountVectorizer())
    vect.train(texts)
    assert len(vect.model.vocabulary_) > 0
    v = vect.vectorize(texts[0]) # test string vectorize
    assert v.shape[0] == 1
    vs = vect.vectorize(texts) # test list vectorize
    assert vs.shape[0] == len(texts)

def test_sequencer():
    vect = Sequencer(original_sequence_length=100, vocab={"i": 0, "love": 1, "my": 2, "mommy": 3, "dad": 4, "dog": 5,
                                                          "data": 6, "science": 7, "is": 8, "cool": 9})
    assert vect.original_sequence_length == 100
    seq = vect.vectorize(texts[0])
    assert seq.shape == (1, vect.original_sequence_length)
    assert seq.flatten()[-1] == vect.vocab[texts[0].split()[-1]]
    seqs = vect.vectorize(texts)
    assert seqs.shape == (len(texts), vect.original_sequence_length)
    assert seqs[-1][-1] == vect.vocab[texts[-1].split()[-1]]

def test_word2vec_embedder():
    vect = Word2VecEmbedder()
    vect.w2v.min_count = 1 # just for testing, so we actually get some words
    vect.train(texts)
    seq = vect.vectorize(texts[0])
    assert seq[0][0] == vect.get_pad_value()
    assert seq[0][-1] == vect.w2v.vocab[texts[0].split()[-1]].index
    seqs = vect.vectorize(texts)
    assert seqs.shape == (len(texts), vect.seqlen)

if __name__ == "__main__":
    test_word2vec_embedder()
